==> task_2.5.0+dfsg.orig.tar.xz: task-2.5.0+dfsg.orig/src/Filter.h <==
////////////////////////////////////////////////////////////////////////////////
//
// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// http://www.opensource.org/licenses/mit-license.php
//
////////////////////////////////////////////////////////////////////////////////

#ifndef INCLUDED_FILTER
#define INCLUDED_FILTER

#include <string>
#include <vector>
#include <Task.h>
#include <Variant.h>

bool domSource (const std::string&, Variant&);

class Filter
{
public:
  Filter ();
  ~Filter ();

  void subset (const std::vector <Task>&, std::vector <Task>&);
  void subset (std::vector <Task>&);
  bool hasFilter ();
  bool hasModifications ();
  bool hasMiscellaneous ();
  bool pendingOnly ();
  void safety ();
  void disableSafety ();

private:
  int  _startCount;
  int  _endCount;
  bool _safety;
};

#endif

==> task_2.5.1+dfsg.orig.tar.xz: task-2.5.1+dfsg.orig/src/Filter.h <==
////////////////////////////////////////////////////////////////////////////////
//
// Copyright 2006 - 2016, Paul Beckingham, Federico Hernandez.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// http://www.opensource.org/licenses/mit-license.php
//
////////////////////////////////////////////////////////////////////////////////

#ifndef INCLUDED_FILTER
#define INCLUDED_FILTER

#include <string>
#include <vector>
#include <Task.h>
#include <Variant.h>

bool domSource (const std::string&, Variant&);

class Filter
{
public:
  Filter () = default;

  void subset (const std::vector <Task>&, std::vector <Task>&);
  void subset (std::vector <Task>&);
  bool hasFilter () const;
  bool pendingOnly () const;
  void safety () const;
  void disableSafety ();

private:
  int  _startCount {0};
  int  _endCount   {0};
  bool _safety     {true};
};

#endif
